@@ -142,11 +142,11 @@ def resize_video_to(
     mode = 'nearest'
 ):
     orig_video_size = video.shape[-1]
+    frames = video.shape[2]
 
-    if orig_video_size == target_image_size:
+    if orig_video_size == target_image_size and default(target_frames, frames) == frames:
         return video
 
-    frames = video.shape[2]
     target_frames = default(target_frames, frames)
 
     target_shape = (target_frames, target_image_size, target_image_size)
@@ -1598,6 +1598,7 @@ class Unet3D(nn.Module):
         text_embeds = None,
         text_mask = None,
         cond_images = None,
+        cond_video_frames = None,
         self_cond = None,
         cond_drop_prob = 0.,
         ignore_time = False
@@ -1622,6 +1623,24 @@ class Unet3D(nn.Module):
         if exists(lowres_cond_img):
             x = torch.cat((x, lowres_cond_img), dim = 1)
 
+            if exists(cond_video_frames):
+                lowres_cond_img = torch.cat((cond_video_frames, lowres_cond_img), dim = 2)
+                cond_video_frames = torch.cat((cond_video_frames, cond_video_frames), dim = 1)
+
+        # conditioning on video frames as a prompt
+        # todo - add post_cond_video_frames as well
+
+        num_preceding_frames = 0
+        if exists(cond_video_frames):
+            cond_video_frames_len = cond_video_frames.shape[2]
+
+            assert divisible_by(cond_video_frames_len, self.total_temporal_divisor)
+
+            cond_video_frames = resize_video_to(cond_video_frames, x.shape[-1])
+            x = torch.cat((cond_video_frames, x), dim = 2)
+
+            num_preceding_frames = cond_video_frames_len
+
         # condition on input image
 
         assert not (self.has_cond_image ^ exists(cond_images)), 'you either requested to condition on an image on the unet, but the conditioning image is not supplied, or vice versa'
@@ -1829,4 +1848,9 @@ class Unet3D(nn.Module):
         if exists(lowres_cond_img):
             x = torch.cat((x, lowres_cond_img), dim = 1)
 
-        return self.final_conv(x)
+        out = self.final_conv(x)
+
+        if num_preceding_frames > 0:
+            out = out[:, :, num_preceding_frames:]
+
+        return out
